@@ -141,8 +141,14 @@ class Session:
 
     def __init__(self, user, password, db_name, encryption_key, logging_handler=None):
         self.db = Database(user, password, db_name, encryption_key, logging_handler)
-        for subclass in Base.__subclasses__():
-            self.create_table(subclass)
+        self._init_tables(Base.__subclasses__())
+
+    def _init_tables(self, tables):
+        for table in tables:
+            if subtables := table.__subclasses__():
+                self._init_tables(subtables)
+            elif getattr(table, "__tablename__"):
+                self.create_table(table)
 
     def close(self):
         self.db.close()
@@ -271,8 +277,7 @@ class Query:
 
     def delete(self):
         to_delete = self.all()
-        for o in to_delete:
-            delete(self.session.db, o)
+        delete(self.session.db, to_delete)
 
     def where(self, *args):
         for key, value in args:
@@ -289,12 +294,17 @@ class Query:
         return self
 
 
-def delete(db, obj):
-    dic = vars(obj)
-    if "id" not in dic:
+def delete(db, to_delete):
+    if not to_delete:
         return
-    query = "DELETE FROM " + obj.__tablename__ + " WHERE id = " + str(dic["id"]) + ";"
-    cursor = db.cursor()
-    cursor.execute(query)
-    db.commit()
-    obj.id = Id()
+    if not isinstance(to_delete, list):
+        to_delete = [to_delete]
+    for obj in to_delete:
+        dic = vars(obj)
+        if "id" not in dic:
+            return
+        query = "DELETE FROM " + obj.__tablename__ + " WHERE id = " + str(dic["id"]) + ";"
+        cursor = db.cursor()
+        cursor.execute(query)
+        db.commit()
+        obj.id = Id()
